SharedArray

Struct SharedArray 

pub struct SharedArray<T>(/* private fields */);
A shared mutable array of T managed by reference counting.

Cloning

The Clone trait implements cloning of the array by reference. Use the clone_content() method to clone the array by content.

Equality

The PartialEq trait performs reference comparison of two arrays.

Hashing

The Hash trait performs hashing of the array by reference.

Implementations

Source

impl<T> SharedArray<T>

pub fn new() -> Self

pub fn get(&self, index: usize) -> Option<T>
where T: Clone,

pub fn set(&mut self, index: usize, value: T)
where T: Clone,

pub fn remove(&mut self, index: usize)

pub fn includes(&self, value: &T) -> bool
where T: PartialEq,

pub fn index_of(&self, value: &T) -> Option<usize>
where T: PartialEq,

pub fn length(&self) -> usize

pub fn push(&mut self, value: T)

pub fn clear(&mut self)

pub fn iter(&self) -> SharedArrayIterator<'_, T>
where T: Clone,

pub fn clone_content(&self) -> Self
where T: Clone,